@@ -15,7 +15,7 @@ from optparse import OptionParser, OptionGroup
 from PIL import Image as PImage
 from PIL import PngImagePlugin
 
-__version__ = '0.2.8.1'
+__version__ = '0.2.9'
 
 
 PADDING_REGEXP = re.compile("^(\d+-?){,3}\d+$")
@@ -702,7 +702,7 @@ class Sprite(object):
                 break
 
         if not images:
-            raise SourceImagesNotFoundError()
+            raise SourceImagesNotFoundError(self.path)
 
         return images
 
@@ -870,6 +870,7 @@ class Sprite(object):
 
             template = self.config.each_template.decode('unicode-escape')
             css_file.write(template % {'class_name': '.%s' % image.class_name,
+                                       'identifier': image.class_name,
                                        'sprite_url': self.image_url(),
                                        'height': height,
                                        'width': width,
@@ -1199,7 +1200,7 @@ class ProjectSpriteManager(BaseManager):
                 self.process_sprite(path=path, name=sprite_name)
 
         if not self.sprites:
-            raise NoSpritesFoldersFoundError()
+            raise NoSpritesFoldersFoundError(self.path)
 
         self.save()
 
@@ -1506,10 +1507,10 @@ def main():
             sys.stderr.write('\t%s => .%s\n' % (rel_path, image.class_name))
         sys.exit(e.error_code)
     except SourceImagesNotFoundError, e:
-        sys.stderr.write("Error: No images found.\n")
+        sys.stderr.write("Error: No images found in %s.\n" % e.args[0])
         sys.exit(e.error_code)
     except NoSpritesFoldersFoundError, e:
-        sys.stderr.write("Error: No sprites folders found.\n")
+        sys.stderr.write("Error: No sprites folders found in %s.\n" % e.args[0])
         sys.exit(e.error_code)
     except InvalidImageOrderingError, e:
         sys.stderr.write("Error: Invalid image ordering %s.\n" % e.args[0])
